package store

import (
	"errors"
	"net/url"
	"regexp"
	"strconv"
)

const letters = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"

var (
	nameRegex   = regexp.MustCompile(`^[a-z0-9()_-]{3,}$`)
	sha256Regex = regexp.MustCompile(`\b[A-Fa-f0-9]{64}\b`)
	secretRegex = regexp.MustCompile(`\b[A-Za-z]{64}\b`)
)

var (
	// AlreadyExists is returned when store already exists.
	AlreadyExists = errors.New("store path already exists")
)

// numerical validates a numerical string.
func numerical(flake string) bool {
	if flake == "" {
		return false
	}
	_, err := strconv.Atoi(flake)
	return err == nil
}

// MatchName determines if str is a valid name.
func MatchName(str string) bool {
	return nameRegex.MatchString(str)
}

// MatchURL determines if str is a valid URL.
func MatchURL(str string) bool {
	u, err := url.Parse(str)
	return err == nil && u.Scheme != "" && u.Host != ""
}
